import asyncio

from mini.apis import errors
from mini.apis.api_sound import ChangeRobotVolume, ChangeRobotVolumeResponse
from mini.apis.api_sound import FetchAudioList, GetAudioListResponse, AudioSearchType
from mini.apis.api_sound import PlayAudio, PlayAudioResponse, AudioStorageType
# from mini.apis.api_sound import PlayOnlineMusic, MusicResponse
from mini.apis.api_sound import StartPlayTTS, StopPlayTTS, ControlTTSResponse
from mini.apis.api_sound import StopAllAudio, StopAudioResponse
from mini.apis.base_api import MiniApiResultType
from mini.dns.dns_browser import WiFiDevice
from test.test_connect import test_connect, shutdown
from test.test_connect import test_get_device_by_name, test_start_run_program



# 测试text合成声音
async def test_play_tts():
    """测试播放tts

    使机器人开始播放一段tts，内容为"你好， 我是悟空， 啦啦啦"，并等待结果

    #ControlTTSResponse.isSuccess : 是否成功

    #ControlTTSResponse.resultCode : 返回码

    """
    # is_serial:串行执行
    # text:要合成的文本
    block: StartPlayTTS = StartPlayTTS(text="你好， 我是悟空， 啦啦啦")
    # 返回元组, response是个ControlTTSResponse
    (resultType, response) = await block.execute()

    print(f'test_play_tts result: {response}')
    # StartPlayTTS block的response包含resultCode和isSuccess
    # 如果resultCode !=0 可以通过errors.get_speech_error_str(response.resultCode)) 查询错误描述信息
    print('resultCode = {0}, error = {1}'.format(response.resultCode, errors.get_speech_error_str(response.resultCode)))

    assert resultType == MiniApiResultType.Success, 'test_play_tts timetout'
    assert response is not None and isinstance(response, ControlTTSResponse), 'test_play_tts result unavailable'
    assert response.isSuccess, 'test_play_tts failed'


async def test_stop_play_tts():
    """测试停止播放tts

    使机器人开始播放一段长文本tts，内容为"你好， 我是悟空， 啦啦啦啦啦啦啦啦啦啦啦啦啦啦啦啦啦啦啦啦啦啦啦啦啦啦啦"，不等待结果
    2s后，使机器人停止播放tts

    #ControlTTSResponse.isSuccess : 是否成功

    #ControlTTSResponse.resultCode : 返回码

    """
    # is_serial:串行执行
    # text:要合成的文本
    block: StartPlayTTS = StartPlayTTS(is_serial=False, text="你好， 我是悟空， 啦啦啦啦啦啦啦啦啦啦啦啦啦啦啦啦啦啦啦啦啦啦啦啦啦啦啦")
    # 返回bool 表示是否发送成功
    await block.execute()

    await asyncio.sleep(2)

    (resultType, response) = await StopPlayTTS().execute()

    print(f'test_stop_play_tts result: {response}')
    # StopPlayTTS block的response包含resultCode和isSuccess
    # 如果resultCode !=0 可以通过errors.get_speech_error_str(response.resultCode)) 查询错误描述信息
    print('resultCode = {0}, error = {1}'.format(response.resultCode, errors.get_speech_error_str(response.resultCode)))

    assert resultType == MiniApiResultType.Success, 'test_stop_play_tts timetout'
    assert response is not None and isinstance(response, ControlTTSResponse), 'test_stop_play_tts result unavailable'
    assert response.isSuccess, 'test_stop_play_tts failed'


# 测试播放音效(在线)
async def test_play_online_audio():
    """测试播放在线音效

    使机器人播放一段在线音效，例如"http://hao.haolingsheng.com/ring/000/995/52513bb6a4546b8822c89034afb8bacb.mp3"

    支持格式有mp3,amr,wav 等

    并等待结果

    #PlayAudioResponse.isSuccess : 是否成功

    #PlayAudioResponse.resultCode : 返回码

    """
    # 播放音效, url表示要播放的音效列表
    block: PlayAudio = PlayAudio(
        url="http://hao.haolingsheng.com/ring/000/995/52513bb6a4546b8822c89034afb8bacb.mp3",
        storage_type=AudioStorageType.NET_PUBLIC)
    # response是个PlayAudioResponse
    (resultType, response) = await block.execute()

    print(f'test_play_online_audio result: {response}')
    print('resultCode = {0}, error = {1}'.format(response.resultCode, errors.get_speech_error_str(response.resultCode)))

    assert resultType == MiniApiResultType.Success, 'test_play_online_audio timetout'
    assert response is not None and isinstance(response, PlayAudioResponse), 'test_play_online_audio result unavailable'
    assert response.isSuccess, 'test_play_online_audio failed'


async def test_play_local_audio():
    """测试播放本地音效

    使机器人播放一段本地内置音效，音效名称为"read_016"，并等待结果

    #PlayAudioResponse.isSuccess : 是否成功

    #PlayAudioResponse.resultCode : 返回码

    """

    block: PlayAudio = PlayAudio(
        url="read_016",
        storage_type=AudioStorageType.PRESET_LOCAL)
    # response是个PlayAudioResponse
    (resultType, response) = await block.execute()

    print(f'test_play_local_audio result: {response}')
    print('resultCode = {0}, error = {1}'.format(response.resultCode, errors.get_speech_error_str(response.resultCode)))

    assert resultType == MiniApiResultType.Success, 'test_play_local_audio timetout'
    assert response is not None and isinstance(response, PlayAudioResponse), 'test_play_local_audio result unavailable'
    assert response.isSuccess, 'test_play_local_audio failed'


# 测试获取机器人的音效资源
async def test_get_audio_list():
    """测试获取音效列表

    获取机器人内置的音效列表，并等待结果

    #GetAudioListResponse.audio ([Audio]) : 音效列表

        #Audio.name : 音效名

        #Audio.suffix : 音效后缀

    #GetAudioListResponse.isSuccess : 是否成功

    #GetAudioListResponse.resultCode : 返回码

    """
    # search_type: AudioSearchType.INNER 是指机器人内置的不可修改的音效, AudioSearchType.CUSTOM 是放置在sdcard/customize/music目录下可别开发者修改的音效
    block: FetchAudioList = FetchAudioList(search_type=AudioSearchType.INNER)
    # response是个GetAudioListResponse
    (resultType, response) = await block.execute()

    print(f'test_get_audio_list result: {response}')

    assert resultType == MiniApiResultType.Success, 'test_get_audio_list timetout'
    assert response is not None and isinstance(response, GetAudioListResponse), 'test_play_audio result unavailable'
    assert response.isSuccess, 'test_get_audio_list failed'


# 测试停止正在播放的tts
async def test_stop_audio_tts():
    """测试停止所有正在播放的音频

    先播放一段tts，3s后，停止所有所有音效，并等待结果

    #StopAudioResponse.isSuccess : 是否成功　

    #StopAudioResponse.resultCode : 返回码

    """
    # 设置is_serial=False, 表示只需将指令发送给机器人,await不需要等机器人执行完结果再返回
    block: StartPlayTTS = StartPlayTTS(is_serial=False, text="你让我说，让我说，不要打断我，不要打断我，不要打断我")
    response = await block.execute()
    print(f'test_stop_audio.play_tts: {response}')
    await asyncio.sleep(3)

    # 停止所有声音
    block: StopAllAudio = StopAllAudio()
    (resultType, response) = await block.execute()

    print(f'test_stop_audio:{response}')

    block: StartPlayTTS = StartPlayTTS(text="第二次, 你让我说，让我说，不要打断我，不要打断我，不要打断我")
    asyncio.create_task(block.execute())
    print(f'test_stop_audio.play_tts: {response}')
    await asyncio.sleep(3)

    assert resultType == MiniApiResultType.Success, 'test_stop_audio timetout'
    assert response is not None and isinstance(response, StopAudioResponse), 'test_stop_audio result unavailable'
    assert response.isSuccess, 'test_stop_audio failed'


# 测试, 改变机器人的音量
async def test_change_robot_volume():
    """调整机器人音量demo

    设置机器人音量为0.5，等待回复结果

    #ChangeRobotVolumeResponse.isSuccess : 是否成功

    #ChangeRobotVolumeResponse.resultCode : 返回码

    """
    # volume: 0~1.0
    block: ChangeRobotVolume = ChangeRobotVolume(volume=0.5)
    # response:ChangeRobotVolumeResponse
    (resultType, response) = await block.execute()

    print(f'test_change_robot_volume result:{response}')

    assert resultType == MiniApiResultType.Success, 'test_change_robot_volume timetout'
    assert response is not None and isinstance(response,
                                               ChangeRobotVolumeResponse), 'test_change_robot_volume result unavailable'
    assert response.isSuccess, 'get_action_list failed'


async def main():
    device: WiFiDevice = await test_get_device_by_name()
    if device:
        await test_connect(device)
        await test_start_run_program()
        await test_speech_recognise_once()
        await test_play_tts()
        await test_stop_play_tts()
        await test_get_audio_list()
        await test_play_local_audio()
        await test_play_online_audio()
        await test_stop_audio_tts()
        await test_change_robot_volume()
        await shutdown()


if __name__ == '__main__':
    asyncio.run(main())



#!/usr/bin/env python3

import enum

from ..apis.base_api import BaseApi, DEFAULT_TIMEOUT
from ..apis.cmdid import _PCProgramCmdId
from ..pb2.codemao_controlmouthlamp_pb2 import ControlMouthRequest, ControlMouthResponse
from ..pb2.codemao_playexpression_pb2 import PlayExpressionRequest, PlayExpressionResponse
from ..pb2.codemao_setmouthlamp_pb2 import SetMouthLampRequest, SetMouthLampResponse
from ..pb2.pccodemao_message_pb2 import Message


@enum.unique
class RobotExpressionType(enum.Enum):
    """
    机器人表情类型

    INNER(内置) : 机器人内置的不可修改的表情文件
    """
    # CUSTOM(自定义) : 放置在sdcard/customize/expresss目录下可被开发者修改的表情文件
    INNER = 0  # 内置表情
    # CUSTOM = 1  # 自定义表情


class PlayExpression(BaseApi):
    """播放内置表情api

    让机器人眼睛演示个表情

    Args:
        is_serial (bool): 是否等待回复，默认True
        express_name (str): 表情名称，不可为空或者None

    #PlayExpressionResponse.isSuccess : 是否成功

    #PlayExpressionResponse.resultCode : 返回码

    """

    def __init__(self, is_serial: bool = True, express_name: str = None):
        assert express_name is not None and len(express_name), 'PlayExpression: expressName should be available'
        self.__is_serial = is_serial
        self.__express_name = express_name
        self.__dir_type = RobotExpressionType.INNER.value

    async def execute(self):
        """
        执行播放表情指令

        Returns:
            PlayExpressionResponse
        """
        timeout = 0
        if self.__is_serial:
            timeout = DEFAULT_TIMEOUT

        request = PlayExpressionRequest()
        request.expressName = self.__express_name
        request.dirType = self.__dir_type

        cmd_id: int = _PCProgramCmdId.PLAY_EXPRESSION_REQUEST.value

        return await self.send(cmd_id, request, timeout)

    def _parse_msg(self, message):
        """

        Args:
            message (Message):待解析的Message对象

        Returns:
            PlayExpressionResponse
        """
        if isinstance(message, Message):
            data = message.bodyData
            response = PlayExpressionResponse()
            response.ParseFromString(data)
            return response
        else:
            return None


@enum.unique
class MouthLampColor(enum.Enum):
    """
    嘴巴灯颜色

    RED : 红色

    GREEN : 绿色

    WHITE : 白色
    """
    RED = 1  # 红色
    GREEN = 2  # 绿色
    WHITE = 4  # 白色


@enum.unique
class MouthLampMode(enum.Enum):
    """
    嘴巴灯模式

    NORMAL(普通模式) : 常亮模式

    BREATH(呼吸模式) : 呼吸模式
    """
    NORMAL = 0  # 普通模式
    BREATH = 1  # 呼吸模式


class SetMouthLamp(BaseApi):
    """设置嘴巴灯api

    设置嘴巴灯的模式、颜色等参数

    当mode=NORMAL时，duration参数起作用，表示常亮多久时间

    当mode=BREATH，breath_duration参数表示多久呼吸一次

    设置生效后，机器人会立即返回设置结果(与设置的duration参数无关)

    Args:
        is_serial (bool): 是否等待回复，默认True
        mode (MouthLampMode): 嘴巴灯模式，默认NORMAL，普通(常亮)模式
        color (MouthLampColor): 嘴巴灯颜色，默认RED，红色
        duration (int): 持续时间，单位为毫秒，-1表示无限时间，当时长设置超过10s，会在10s内返回结果
        breath_duration (int):闪烁一次时长，单位为毫秒

    #SetMouthLampResponse.isSuccess : 是否成功

    #SetMouthLampResponse.resultCode : 返回码
    """

    def __init__(self, is_serial: bool = True, mode: MouthLampMode = MouthLampMode.NORMAL,
                 color: MouthLampColor = MouthLampColor.RED, duration: int = 1000, breath_duration: int = 1000):
        assert isinstance(mode, MouthLampMode), 'SetMouthLamp: mode should be MouthLampMode instance'
        assert isinstance(color, MouthLampColor), 'SetMouthLamp: color should be MouthLampColor instance'
        self.serial = is_serial
        self.__is_serial = self.serial
        self.__mode = mode.value
        self.__color = color.value
        self.__duration = duration
        self.__breath_duration = breath_duration

    async def execute(self):
        """
        执行设置设置嘴巴灯指令

        Returns:
            SetMouthLampResponse
        """
        timeout = 0
        if self.__is_serial:
            timeout = DEFAULT_TIMEOUT

        request = SetMouthLampRequest()
        request.model = self.__mode
        request.color = self.__color
        if request.color == 4:
            request.redValue = 0xff
            request.greenValue = 0xff
            request.blueValue = 0xff

        request.duration = self.__duration
        request.breathDuration = self.__breath_duration

        cmd_id = _PCProgramCmdId.SET_MOUTH_LAMP_REQUEST.value
        return await self.send(cmd_id, request, timeout)

    def _parse_msg(self, message):
        """

        Args:
            message (Message):待解析的Message对象

        Returns:
            SetMouthLampResponse
        """
        if isinstance(message, Message):
            data = message.bodyData
            response = SetMouthLampResponse()
            response.ParseFromString(data)
            return response
        else:
            return None


class ControlMouthLamp(BaseApi):
    """控制嘴巴灯开关api

    打开/关闭嘴巴灯

    Args:
        is_serial (bool): 是否等待回复，默认True
        is_open (bool): 是否开启嘴巴灯 默认true，开启嘴巴灯

    #ControlMouthResponse.isSuccess : 是否成功

    #ControlMouthResponse.resultCode : 返回码
    """

    def __init__(self, is_serial: bool = True, is_open: bool = True):

        self.__is_serial = is_serial
        self.__is_open = is_open

    async def execute(self):
        """
        执行控制嘴巴灯指令

        Returns:
            ControlMouthResponse
        """
        timeout = 0
        if self.__is_serial:
            timeout = DEFAULT_TIMEOUT

        request = ControlMouthRequest()
        request.isOpen = self.__is_open

        cmd_id = _PCProgramCmdId.SWITCH_MOUTH_LAMP_REQUEST.value

        return await self.send(cmd_id, request, timeout)

    def _parse_msg(self, message):
        """

        Args:
            message (Message):待解析的Message对象

        Returns:
            ControlMouthResponse
        """
        if isinstance(message, Message):
            data = message.bodyData
            response = ControlMouthResponse()
            response.ParseFromString(data)
            return response
        else:
            return None



import mini
import mini.pkg_tool as pt

device = "0717"

py_script_tts = """import asyncio
import mini
from mini.apis import errors
from mini.apis.api_sound import StartPlayTTS, ControlTTSResponse
from mini.apis.base_api import MiniApiResultType


# 测试text合成声音
async def test_play_tts():
	wifiDevice = mini.WiFiDevice(port=8800)
	sdk_connect = await mini.mini_sdk.connect(wifiDevice)
	print('connect device {0} {1}'.format(wifiDevice, sdk_connect))
	if not sdk_connect:
		print("connect failed.......................")
		return
	await mini.mini_sdk.enter_program()
	# text:要合成的文本
	block: StartPlayTTS = StartPlayTTS(text="两间公司合并后，新公司将以Cenovus名称继续营运，总部维持于加拿大艾伯塔省卡尔加里。交易已获赫斯基能源公司与Cenovus公司双方董事局一致通过，预期将于明年第一季度完成交易。根据安排协议条款，赫斯基能源股东将会收取0.7845股Cenovus普通股，以及可认购0.0651股Cenovus普通股的认股权证，交换所拥有的每股赫斯基能源普通股。预期交易完成后及行使任何认股权证前，Cenovus股东将拥有合并公司约60.775%股权，赫斯基能源股东则占约39.225%股权。")
	# 返回元组, response是个ControlTTSResponse
	(resultType, response) = await block.execute()

	print(f'test_play_tts result: {response}')
	# StartPlayTTS block的response包含resultCode和isSuccess
	# 如果resultCode !=0 可以通过errors.get_speech_error_str(response.resultCode)) 查询错误描述信息
	print('resultCode = {0}, error = {1}'.format(response.resultCode, errors.get_speech_error_str(response.resultCode)))

	assert resultType == MiniApiResultType.Success, 'test_play_tts timetout'
	assert response is not None and isinstance(response, ControlTTSResponse), 'test_play_tts result unavailable'
	assert response.isSuccess, 'test_play_tts failed'

	await mini.mini_sdk.quit_program()


async def main():
	await test_play_tts()


if __name__ == '__main__':
	asyncio.run(main())"""

py_script_dance = """import asyncio

import mini
from mini.apis import errors
from mini.apis.api_behavior import StartBehavior
from mini.apis.base_api import MiniApiResultType
from mini.pb2.codemao_controlbehavior_pb2 import ControlBehaviorResponse


# 测试text合成声音
async def test_control_behavior():
    wifiDevice = mini.WiFiDevice(port=8800)
    sdk_connect = await mini.mini_sdk.connect(wifiDevice)
    print('connect device {0} {1}'.format(wifiDevice, sdk_connect))
    if not sdk_connect:
        print("connect failed.......................")
        return
    await mini.mini_sdk.enter_program()
    # text:要合成的文本
    block: StartBehavior = StartBehavior(name="012")
    # 返回元组, response是个ControlTTSResponse
    (resultType, response) = await block.execute()

    print(f'test_control_behavior result: {response}')
    # StartPlayTTS block的response包含resultCode和isSuccess
    # 如果resultCode !=0 可以通过errors.get_speech_error_str(response.resultCode)) 查询错误描述信息
    print('resultCode = {0}, error = {1}'.format(response.resultCode, errors.get_express_error_str(response.resultCode)))

    assert resultType == MiniApiResultType.Success, 'test_control_behavior timetout'
    assert response is not None and isinstance(response,
                                               ControlBehaviorResponse), 'test_control_behavior result unavailable'
    assert response.isSuccess, 'control_behavior failed'

    await mini.mini_sdk.quit_program()


async def main():
    await test_control_behavior()


if __name__ == '__main__':
    asyncio.run(main())
"""

fileName = "DanceTest.py"


def test_upload_script():
    # 上传脚本到机器人
    pt.upload_script(1, device, fileName, bytes(py_script_tts, encoding="utf-8"))


def test_check_upload_script():
    # 检查脚本是否已上传到机器人
    pt.upload_script(2, device, fileName)


def test_run_upload_script():
    # 执行已上传的脚本
    pt.upload_script(3, device, fileName)


def test_stop_upload_script():
    # 执行已上传的脚本
    pt.upload_script(4, device)


def test_list_upload_script():
    # 获取已上传的脚本列表
    pt.upload_script(5, device)


async def release():
    await mini.mini_sdk.release()

if __name__ == '__main__':
    # test_upload_script()
    test_check_upload_script()
    # test_run_upload_script()
    # test_stop_upload_script()
    # test_list_upload_script()



#!/usr/bin/env python3

from ..apis.api_config import LanType, ServicePlatform
from ..apis.base_api import BaseApi, DEFAULT_TIMEOUT
from ..apis.cmdid import _PCProgramCmdId
from ..pb2.cloudtranslate_pb2 import Translate
from ..pb2.cloudwiki_pb2 import WiKi
from ..pb2.codemao_translate_pb2 import TranslateResponse, TranslateRequest
from ..pb2.codemao_wiki_pb2 import WikiRequest, WikiResponse
from ..pb2.pccodemao_message_pb2 import Message


class QueryWiKi(BaseApi):
    """百科api

    默认腾讯百科

    Args:
        is_serial (bool): 是否等待回复，默认True
        query (str): 查询的内容，不能为空或None

    #WikiResponse.isSuccess : 是否成功

    #WikiResponse.resultCode : 返回码
    """

    def __init__(self, is_serial: bool = True, query: str = None):
        assert isinstance(query, str) and len(query), 'QueryWiKi query should be available'
        self.__is_serial = is_serial
        self.__query = query
        self.__platform = ServicePlatform.TENCENT.value

    async def execute(self):
        """
        执行百科指令

        Returns:
            WikiResponse

        """
        timeout = 0
        if self.__is_serial:
            timeout = DEFAULT_TIMEOUT

        wiki = WiKi()
        wiki.query = self.__query
        wiki.platform = self.__platform

        request = WikiRequest()
        request.wiki.CopyFrom(wiki)

        cmd_id = _PCProgramCmdId.WIKI_REQUEST.value

        return await self.send(cmd_id, request, timeout)

    def _parse_msg(self, message):
        """

        Args:
            message (Message):待解析的Message对象

        Returns:
            WikiResponse
        """
        if isinstance(message, Message):
            data = message.bodyData
            response = WikiResponse()
            response.ParseFromString(data)
            return response
        else:
            return None


class StartTranslate(BaseApi):
    """翻译api

    默认百度翻译

    Args:
        is_serial (bool): 是否等待回复，默认True
        query (str): 翻译的内容，不能为空或None
        from_lan (LanType): 翻译的原文语言，默认CN，中文
        to_lan (LanType):  翻译的目标语言，默认EN，英文
        platform (ServicePlatform): 翻译平台，默认BAIDU，使用百度翻译

    #TranslateResponse.isSuccess : 是否成功

    #TranslateResponse.resultCode : 返回码

    """

    def __init__(self, is_serial: bool = True, query: str = None,
                 from_lan: LanType = LanType.CN,
                 to_lan: LanType = LanType.EN,
                 platform: ServicePlatform = ServicePlatform.BAIDU):
        assert isinstance(query, str) and len(query) > 0, 'Translate : query should be available'
        assert isinstance(from_lan, LanType), 'Translate : from_lan should be LanType instance'
        assert isinstance(to_lan, LanType), 'Translate : to_lan should be LanType instance'
        assert isinstance(platform, ServicePlatform), 'Translate : platform should be ServicePlatform instance'
        self.__is_serial = is_serial
        self.__query = query
        # self.__prefix = prefix
        # self.__suffix = suffix
        self.__from_lan = from_lan.value
        self.__to_lan = to_lan.value
        self.__platform = platform.value

    async def execute(self):
        """
        执行翻译指令

        Returns:
            TranslateResponse
        """
        timeout = 0
        if self.__is_serial:
            timeout = DEFAULT_TIMEOUT

        translate = Translate()
        translate.query = self.__query
        # translate.prefix = self.__prefix
        # translate.suffix = self.__suffix
        translate.platform = self.__platform
        # translate.from = self.__fromLan
        setattr(translate, "from", self.__from_lan)
        translate.to = self.__to_lan
        # setattr(translate, "to", self.__toLan)

        request = TranslateRequest()
        request.translate.CopyFrom(translate)

        cmd_id = _PCProgramCmdId.TRANSLATE_REQUEST.value
        return await self.send(cmd_id, request, timeout)

    def _parse_msg(self, message):
        """

        Args:
            message (Message):待解析的Message对象

        Returns:
            TranslateResponse
        """
        if isinstance(message, Message):
            data = message.bodyData
            response = TranslateResponse()
            response.ParseFromString(data)
            return response
        else:
            return None



#!/usr/bin/env python3
import enum

from ..apis.base_api import BaseApi, DEFAULT_TIMEOUT
from ..apis.cmdid import _PCProgramCmdId
from ..pb2.codemao_getactionlist_pb2 import GetActionListRequest, GetActionListResponse
from ..pb2.codemao_moverobot_pb2 import MoveRobotRequest, MoveRobotResponse
from ..pb2.codemao_playaction_pb2 import PlayActionRequest, PlayActionResponse
from ..pb2.codemao_playcustomaction_pb2 import PlayCustomActionRequest, PlayCustomActionResponse
from ..pb2.codemao_stopaction_pb2 import StopActionRequest, StopActionResponse
from ..pb2.codemao_stopcustomaction_pb2 import StopCustomActionRequest, StopCustomActionResponse
from ..pb2.pccodemao_message_pb2 import Message


class PlayAction(BaseApi):
    """执行内置动作api

    机器人执行一个指定名称的内置动作
    动作名称可用GetActionList获取

    Args:
        is_serial (bool): 是否等待回复，默认True
        action_name (str): 动作名称，不能为none或空字符串

    #PlayActionResponse.isSuccess : 是否成功

    #PlayActionResponse.resultCode : 返回码

    """

    def __init__(self, is_serial: bool = True, action_name: str = None):
        """执行动作api初始化
        """
        assert isinstance(action_name, str) and action_name is not None and len(
            action_name), 'PlayAction actionName should be available'
        self.__is_serial = is_serial
        self.__action_name = action_name

    async def execute(self):
        """发送执行动作指令

        Returns:
            PlayActionResponse
        """
        timeout = 0
        if self.__is_serial:
            timeout = DEFAULT_TIMEOUT
        request = PlayActionRequest()
        request.actionName = self.__action_name

        cmd_id = _PCProgramCmdId.PLAY_ACTION_REQUEST.value
        return await self.send(cmd_id, request, timeout)

    def _parse_msg(self, message):
        """解析回复指令

        Args:
            message (Message):待解析的Message对象

        Returns:
            PlayActionResponse
        """
        if isinstance(message, Message):
            data = message.bodyData
            response = PlayActionResponse()
            response.ParseFromString(data)
            return response
        else:
            return None


class StopAllAction(BaseApi):
    """停止所有动作api

    停止所有正在执行的动作, 停止指定的自定义动作, 如果动作是一个不可打断的动作, StopCustomActionResponse.resultCode = 403

    Args
        is_serial (bool): 是否等待回复，默认True

    """

    def __init__(self, is_serial: bool = True):
        self.__is_serial = is_serial

    async def execute(self):
        """
        发送停止所有动作指令

        Returns:
            StopActionResponse
        """
        timeout = 0
        if self.__is_serial:
            timeout = DEFAULT_TIMEOUT

        request = StopActionRequest()

        cmd_id = _PCProgramCmdId.STOP_ACTION_REQUEST.value
        return await self.send(cmd_id, request, timeout)

    def _parse_msg(self, message):
        """

        Args:
            message (Message):待解析的Message对象

        Returns:
            StopActionResponse

            #StopCustomActionResponse.isSuccess : 是否成功

            #StopCustomActionResponse.resultCode : 返回码

        """
        if isinstance(message, Message):
            data = message.bodyData
            response = StopActionResponse()
            response.ParseFromString(data)
            return response
        else:
            return None


@enum.unique
class MoveRobotDirection(enum.Enum):
    """机器人移动方向

    FORWARD :  向前

    BACKWARD : 向后

    LEFTWARD : 向左

    RIGHTWARD : 向右
    """
    FORWARD = 3  # 向前
    BACKWARD = 4  # 向后
    LEFTWARD = 1  # 向左
    RIGHTWARD = 2  # 向右


class MoveRobot(BaseApi):
    """控制机器人移动api

    控制机器人往某个方向(MoveRobotDirection)移动n步

    Args:
        is_serial (bool): 是否等待回复，默认True
        direction (MoveRobotDirection): 机器人移动方向，默认FORWARD，向前移动
        step (int): 步数，默认1步

    #MoveRobotResponse.isSuccess : 是否成功　

    #MoveRobotResponse.code : 返回码

    """

    def __init__(self, is_serial: bool = True, direction: MoveRobotDirection = MoveRobotDirection.FORWARD,
                 step: int = 1):
        assert isinstance(direction, MoveRobotDirection), 'MoveRobot : direction should be MoveRobotDirection instance'
        assert isinstance(step, int) and step > 0, 'MoveRobot : step should be Positive'
        self.__is_serial = is_serial
        self.__direction = direction.value
        self.__step = step

    async def execute(self):
        """发送机器人移动指令

        Returns:
            MoveRobotResponse
        """
        timeout = 0
        if self.__is_serial:
            timeout = DEFAULT_TIMEOUT

        request = MoveRobotRequest()
        request.direction = self.__direction
        request.step = self.__step

        cmd_id = _PCProgramCmdId.MOVE_ROBOT_REQUEST.value
        return await self.send(cmd_id, request, timeout)

    def _parse_msg(self, message):
        """

        Args:
            message (Message):待解析的Message对象

        Returns:
            MoveRobotResponse
        """
        if isinstance(message, Message):
            data = message.bodyData
            response = MoveRobotResponse()
            response.ParseFromString(data)
            return response
        else:
            return None


@enum.unique
class RobotActionType(enum.Enum):
    """
    机器人动作类型

    INNER(内置)：机器人内置的不可修改的动作文件

    CUSTOM(自定义): 放置在sdcard/customize/actions目录下可被开发者修改的动作文件

    """
    INNER = 0  # 内置
    CUSTOM = 1  # 自定义


class GetActionList(BaseApi):
    """获取机器人动作列表api

    获取存储在机器人本地(内置/自定义)的动作文件列表

    Args:
        is_serial (bool): 是否等待回复，默认True
        action_type (RobotActionType): 动作类型，默认为INNER，内置动作

    #GetActionListResponse.actionList ([str]) : 动作列表，str数组

    #GetActionListResponse.isSuccess : 是否成功

    #GetActionListResponse.resultCode : 返回码

    """

    def __init__(self, is_serial: bool = True, action_type: RobotActionType = RobotActionType.INNER):
        assert isinstance(action_type, RobotActionType), 'GetActionList : action_type should be RobotActionType ' \
                                                         'instance '
        self.__is_serial = is_serial
        self.__action_type = action_type.value

    async def execute(self):
        """发送获取机器人动作列表指令

        Returns:
            GetActionListResponse
        """
        timeout = 0
        if self.__is_serial:
            timeout = DEFAULT_TIMEOUT

        request = GetActionListRequest()
        request.actionType = self.__action_type

        cmd_id = _PCProgramCmdId.GET_ACTION_LIST.value

        return await self.send(cmd_id, request, timeout)

    def _parse_msg(self, message):
        """

        Args:
            message (Message):待解析的Message对象

        Returns:
            GetActionListResponse
        """
        if isinstance(message, Message):
            data = message.bodyData
            response = GetActionListResponse()
            response.ParseFromString(data)
            return response
        else:
            return None


class PlayCustomAction(BaseApi):
    """执行自定义动作api

    让机器人执行一个指定名称的自定义动作
    动作名称可用GetActionList获取

    Args:
        is_serial (bool): 是否等待回复，默认True
        action_name (str): 自定义动作名称，不可为空或者None

    #PlayCustomActionResponse.isSuccess : 是否成功

    #PlayCustomActionResponse.resultCode : 返回码
    """

    def __init__(self, is_serial: bool = True, action_name: str = None):

        assert isinstance(action_name, str) and len(action_name) > 0, 'PlayCustomAction : actionName should be ' \
                                                                      'available '
        self.__is_serial = is_serial
        self.__action_name = action_name

    async def execute(self):
        """发送执行自定义动作指令

        Returns:
            PlayCustomActionResponse
        """
        timeout = 0
        if self.__is_serial:
            timeout = DEFAULT_TIMEOUT

        request = PlayCustomActionRequest()
        request.actionName = self.__action_name

        cmd_id = _PCProgramCmdId.PLAY_CUSTOM_ACTION_REQUEST.value
        return await self.send(cmd_id, request, timeout)

    def _parse_msg(self, message):
        """

        Args:
            message (Message):待解析的Message对象

        Returns:
            PlayCustomActionResponse
        """

        if isinstance(message, Message):
            data = message.bodyData
            response = PlayCustomActionResponse()
            response.ParseFromString(data)
            return response
        else:
            return None


class StopCustomAction(BaseApi):
    """停止自定义动作api

    停止指定的自定义动作, 如果动作是一个不可打断的动作, StopCustomActionResponse.resultCode = 403

    Args:
        is_serial (bool): 是否等待回复，默认True
        action_name (str): 自定义动作名称，不可为空或None

    #StopCustomActionResponse.isSuccess : 是否成功

    #StopCustomActionResponse.resultCode : 返回码

    """

    def __init__(self, is_serial: bool = True, action_name: str = None):
        assert isinstance(action_name, str) and len(action_name) > 0, 'StopCustomAction actionName should be available'
        self.__is_serial = is_serial
        self.__action_name = action_name

    async def execute(self):
        """执行停止自定义动作指令

        Returns:
            StopCustomActionResponse
        """
        timeout = 0
        if self.__is_serial:
            timeout = DEFAULT_TIMEOUT

        request = StopCustomActionRequest()
        request.actionName = self.__action_name

        cmd_id = _PCProgramCmdId.STOP_CUSTOM_ACTION_REQUEST.value
        return await self.send(cmd_id, request, timeout)

    def _parse_msg(self, message):
        """

        Args:
            message (Message):待解析的Message对象

        Returns:
            StopCustomActionResponse
        """

        if isinstance(message, Message):
            data = message.bodyData
            response = StopCustomActionResponse()
            response.ParseFromString(data)
            return response
        else:
            return None



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: pccodemao_getrobotlanguage.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()

DESCRIPTOR = _descriptor.FileDescriptor(
    name='pccodemao_getrobotlanguage.proto',
    package='packet',
    syntax='proto3',
    serialized_options=b'\n\034com.ubtrobot.pccodemao.protoB\020GetRobotLanguage',
    serialized_pb=b'\n pccodemao_getrobotlanguage.proto\x12\x06packet\"\x19\n\x17GetRobotLanguageRequest\"S\n\x18GetRobotLanguageResponse\x12\x11\n\tisSuccess\x18\x01 \x01(\x08\x12\x12\n\nresultCode\x18\x02 \x01(\x05\x12\x10\n\x08language\x18\x03 \x01(\tB0\n\x1c\x63om.ubtrobot.pccodemao.protoB\x10GetRobotLanguageb\x06proto3'
)

_GETROBOTLANGUAGEREQUEST = _descriptor.Descriptor(
    name='GetRobotLanguageRequest',
    full_name='packet.GetRobotLanguageRequest',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=44,
    serialized_end=69,
)

_GETROBOTLANGUAGERESPONSE = _descriptor.Descriptor(
    name='GetRobotLanguageResponse',
    full_name='packet.GetRobotLanguageResponse',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='isSuccess', full_name='packet.GetRobotLanguageResponse.isSuccess', index=0,
            number=1, type=8, cpp_type=7, label=1,
            has_default_value=False, default_value=False,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='resultCode', full_name='packet.GetRobotLanguageResponse.resultCode', index=1,
            number=2, type=5, cpp_type=1, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='language', full_name='packet.GetRobotLanguageResponse.language', index=2,
            number=3, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=b"".decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=71,
    serialized_end=154,
)

DESCRIPTOR.message_types_by_name['GetRobotLanguageRequest'] = _GETROBOTLANGUAGEREQUEST
DESCRIPTOR.message_types_by_name['GetRobotLanguageResponse'] = _GETROBOTLANGUAGERESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetRobotLanguageRequest = _reflection.GeneratedProtocolMessageType('GetRobotLanguageRequest', (_message.Message,), {
    'DESCRIPTOR': _GETROBOTLANGUAGEREQUEST,
    '__module__': 'pccodemao_getrobotlanguage_pb2'
    # @@protoc_insertion_point(class_scope:packet.GetRobotLanguageRequest)
})
_sym_db.RegisterMessage(GetRobotLanguageRequest)

GetRobotLanguageResponse = _reflection.GeneratedProtocolMessageType('GetRobotLanguageResponse', (_message.Message,), {
    'DESCRIPTOR': _GETROBOTLANGUAGERESPONSE,
    '__module__': 'pccodemao_getrobotlanguage_pb2'
    # @@protoc_insertion_point(class_scope:packet.GetRobotLanguageResponse)
})
_sym_db.RegisterMessage(GetRobotLanguageResponse)

DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



#!/usr/bin/env python
# coding=utf-8
import os

import setuptools

with open("README.md", "r", encoding="UTF-8") as f:
    long_desc = f.read()

with open("LICENSE", "r", encoding="UTF-8") as f:
    license_txt = f.read()

setuptools.setup(
    name="alphamini",
    version="1.1.1",
    author='logic.peng',
    author_email='logic.peng@ubtrobot.com',
    description="python sdk for ubtech alpha mini robot",
    long_description=long_desc,
    long_description_content_type="text/markdown",
    license="GPLv3",
    python_requires='>=3.7',
    # url="",
    packages=setuptools.find_packages(exclude=["*.test", "*.test.*"]),  # 排除掉测试包
    # packages=setuptools.find_namespace_packages(where=os.curdir + "/mini"),
    # packages=['mini'],
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    entry_points={
        'console_scripts': [
            'setup_py_pkg = mini.tool.script.cli:cli_setup_py_pkg',
            'install_py_pkg = mini.tool.script.cli:cli_install_py_pkg',
            'uninstall_py_pkg = mini.tool.script.cli:cli_uninstall_py_pkg',
            'run_py_pkg = mini.tool.script.cli:cli_run_py_pkg',
            'run_cmd = mini.tool.script.cli:cli_run_cmd',
            'query_py_pkg = mini.tool.script.cli:cli_show_py_pkg',
            'list_py_pkg = mini.tool.script.cli:cli_list_py_pkg',
            'adb_enable = mini.tool.script.cli:cli_adb_enable',
            'adb_disable = mini.tool.script.cli:cli_adb_disable',
        ],
    },
    install_requires=[
        'websockets',
        'ifaddr',
        'protobuf',
        'click',
    ],
    zip_safe=False
)



#!/usr/bin/env python3

import enum

from mini.pb2.codemao_speechrecognise_pb2 import SpeechRecogniseRequest, SpeechRecogniseResponse

from ..apis.api_config import ServicePlatform
from ..apis.base_api import BaseApi, DEFAULT_TIMEOUT
from ..apis.cmdid import _PCProgramCmdId
from ..pb2 import cloudstorageurls_pb2
from ..pb2.codemao_changerobotvolume_pb2 import ChangeRobotVolumeRequest, ChangeRobotVolumeResponse
from ..pb2.codemao_controlrobotrecord_pb2 import ControlRobotRecordRequest, ControlRobotRecordResponse
from ..pb2.codemao_controltts_pb2 import ControlTTSRequest, ControlTTSResponse
from ..pb2.codemao_getaudiolist_pb2 import GetAudioListRequest, GetAudioListResponse
from ..pb2.codemao_playaudio_pb2 import PlayAudioRequest, PlayAudioResponse
from ..pb2.codemao_playonlinemusic_pb2 import MusicRequest, MusicResponse
from ..pb2.codemao_stopaudio_pb2 import StopAudioRequest, StopAudioResponse
from ..pb2.pccodemao_message_pb2 import Message


@enum.unique
class TTSControlType(enum.Enum):
    """
    TTS控制类型

    START : 开始播放tts

    STOP : 停止播放tts
    """
    START = 1  # 播放
    STOP = 0  # 停止


class StartPlayTTS(BaseApi):
    """开始播放TTS api

    机器人播放合成的TTS语音

    Args:
        is_serial (bool): 是否等待回复，默认True
        text (str): 播放的文本，不能为空或者None

    #ControlTTSResponse.isSuccess : 是否成功

    #ControlTTSResponse.resultCode : 返回码
    """

    def __init__(self, is_serial: bool = True, text: str = None):
        assert isinstance(text, str) and len(text), 'StartPlayTTS : tts text should be available'
        self.__is_serial = is_serial
        self.__text = text
        self.__type = TTSControlType.START.value

    async def execute(self):
        """
        执行开始播放TTS指令

        Returns:
            ControlTTSResponse

        """
        timeout = 0
        if self.__is_serial:
            timeout = DEFAULT_TIMEOUT

        request = ControlTTSRequest()
        request.text = self.__text
        request.type = self.__type

        cmd_id = _PCProgramCmdId.PLAY_TTS_REQUEST.value

        return await self.send(cmd_id, request, timeout)

    def _parse_msg(self, message):
        """

        Args:
            message (Message):待解析的Message对象

        Returns:
            ControlTTSResponse
        """
        if isinstance(message, Message):
            data = message.bodyData
            response = ControlTTSResponse()
            response.ParseFromString(data)
            return response
        else:
            return None



class StopPlayTTS(BaseApi):
    """停止播放TTS api

    机器人停止播放TTS语音

    Args:
        is_serial (bool): 是否等待回复，默认True

    #ControlTTSResponse.isSuccess : 是否成功

    #ControlTTSResponse.resultCode : 返回码
    """

    def __init__(self, is_serial: bool = True):
        self.__isSerial = is_serial
        self.__type = TTSControlType.STOP.value

    async def execute(self):
        """
        执行停止播放TTS指令

        Returns:
            ControlTTSResponse

        """
        timeout = 0
        if self.__isSerial:
            timeout = DEFAULT_TIMEOUT

        request = ControlTTSRequest()
        request.type = self.__type

        cmd_id = _PCProgramCmdId.PLAY_TTS_REQUEST.value

        return await self.send(cmd_id, request, timeout)

    def _parse_msg(self, message):
        """

        Args:
            message (Message):待解析的Message对象

        Returns:
            ControlTTSResponse

        """
        if isinstance(message, Message):
            data = message.bodyData
            response = ControlTTSResponse()
            response.ParseFromString(data)
            return response
        else:
            return None


class _PlayTTS(BaseApi):
    """播放/停止TTS api

    机器人播放合成的TTS语音

    control_type为STOP时，表示停止所有正在播放的TTS

    Args:
        is_serial (bool): 是否等待回复，默认True
        text (str): 播放的文本，不能为空或者None
        control_type (TTSControlType): 控制类型，默认START，开始播放

    #ControlTTSResponse.isSuccess : 是否成功

    #ControlTTSResponse.resultCode : 返回码
    """

    def __init__(self, is_serial: bool = True, text: str = None, control_type: TTSControlType = TTSControlType.START):
        assert text is not None and len(text), 'tts text should be available'
        self.__isSerial = is_serial
        self.__text = text
        self.__type = control_type.value

    async def execute(self):
        """
        执行控制TTS指令

        Returns:
            ControlTTSResponse
        """
        timeout = 0
        if self.__isSerial:
            timeout = DEFAULT_TIMEOUT

        request = ControlTTSRequest()
        request.text = self.__text
        request.type = self.__type

        cmd_id = _PCProgramCmdId.PLAY_TTS_REQUEST.value

        return await self.send(cmd_id, request, timeout)

    def _parse_msg(self, message):
        """

        Args:
            message (Message):待解析的Message对象

        Returns:
            ControlTTSResponse
        """
        if isinstance(message, Message):
            data = message.bodyData
            response = ControlTTSResponse()
            response.ParseFromString(data)
            return response
        else:
            return None


@enum.unique
class AudioStorageType(enum.Enum):
    """
    音频存储类型

    NET_PUBLIC : 公网

    PRESET_LOCAL : 机器人本地内置

    CUSTOMIZE_LOCAL : 机器人本地自定义

    """
    # ALIYUN_PRIVATE = 1  # 阿里私有云
    NET_PUBLIC = 2  # 公网
    PRESET_LOCAL = 3  # 本地内置
    CUSTOMIZE_LOCAL = 4  # 本地自定义


class PlayAudio(BaseApi):
    """播放音频api

    机器人播放指定的音频, 支持mp3,wav,amr等

    Args:
        is_serial (bool): 是否等待回复，默认True
        url (str): 音频地址，当storage_type为NET_PUBLIC，url为音频文件网址；当storage_type为PRESET_LOCAL/CUSTOMIZE_LOCAL时，
                    url为本地音频名称（本地音频名称可通过FetchAudioList接口获取）
        storage_type (AudioStorageType): 音频存储类型，默认NET_PUBLIC，公网
        volume (float): 音量大小，范围[0.0,1.0]，默认1.0

    #PlayAudioResponse.isSuccess : 是否成功

    #PlayAudioResponse.resultCode : 返回码

    """

    def __init__(self, is_serial: bool = True, url: str = None,
                 storage_type: AudioStorageType = AudioStorageType.NET_PUBLIC, volume: float = 1.0):

        assert isinstance(url, str) and len(url), 'PlayAudio : url should be available'
        assert isinstance(volume, float) and 0 <= volume <= 1.0, 'PlayAudio : volume should be in range[0,1]'
        assert isinstance(storage_type, AudioStorageType), 'PlayAudio : storage_type shoule be AudioStorageType ' \
                                                           'instance '
        self.__is_serial = is_serial
        self.__url = url
        self.__volume = volume
        self.__cloudStorageType = storage_type.value

    async def execute(self):
        """
        执行播放音频指令

        Returns:
            PlayAudioResponse
        """
        timeout = 0
        if self.__is_serial:
            timeout = DEFAULT_TIMEOUT

        cloud = cloudstorageurls_pb2.CloudStorage()
        cloud.type = self.__cloudStorageType
        cloud.url.extend([self.__url])

        request = PlayAudioRequest()

        request.cloud.CopyFrom(cloud)
        request.volume = self.__volume

        cmd_id = _PCProgramCmdId.PLAY_AUDIO_REQUEST.value

        return await self.send(cmd_id, request, timeout)

    def _parse_msg(self, message):
        """

        Args:
            message (Message):待解析的Message对象

        Returns:
            PlayAudioResponse
        """
        if isinstance(message, Message):
            data = message.bodyData
            response = PlayAudioResponse()
            response.ParseFromString(data)
            return response
        else:
            return None


class StopAllAudio(BaseApi):
    """停止所有音频api

    机器人停止所有正在播放的音频

    Args:
        is_serial (bool): 是否等待回复，默认True

    #StopAudioResponse.isSuccess : 是否成功　

    #StopAudioResponse.resultCode : 返回码

    """

    def __init__(self, is_serial: bool = True):
        self.__is_serial = is_serial

    async def execute(self):
        """
        执行停止所有音频指令

        Returns:
            StopAudioResponse
        """
        timeout = 0
        if self.__is_serial:
            timeout = DEFAULT_TIMEOUT

        request = StopAudioRequest()

        cmd_id = _PCProgramCmdId.STOP_AUDIO_REQUEST.value

        return await self.send(cmd_id, request, timeout)

    def _parse_msg(self, message):
        """

        Args:
            message (Message):待解析的Message对象

        Returns:
            StopAudioResponse
        """
        if isinstance(message, Message):
            data = message.bodyData
            response = StopAudioResponse()
            response.ParseFromString(data)
            return response
        else:
            return None


@enum.unique
class AudioSearchType(enum.Enum):
    """
    音频查询类型

    INNER(内置) : 机器人内置的不可修改的音效,

    CUSTOM(自定义) : 放置在sdcard/customize/music目录下可被开发者修改的音效
    """
    INNER = 0  # 内置
    CUSTOM = 1  # 自定义


class FetchAudioList(BaseApi):
    """获取机器人的音频列表api

    获取存储在机器人rom或者sdcard中的音频列表

    Args:
        is_serial (bool): 是否等待回复，默认True
        search_type (AudioSearchType): 查询类型，默认INNER，机器人内置

    #GetAudioListResponse.audio ([Audio]) : 音效列表

    #Audio.name : 音效名

    #Audio.suffix : 音效后缀

    #GetAudioListResponse.isSuccess : 是否成功

    #GetAudioListResponse.resultCode : 返回码

    """

    def __init__(self, is_serial: bool = True, search_type: AudioSearchType = AudioSearchType.INNER):
        assert isinstance(search_type, AudioSearchType), 'FetchAudioList : search_type should be AudioSearchType ' \
                                                         'instance '
        self.__is_serial = is_serial
        self.__search_type = search_type.value

    async def execute(self):
        """
        执行获取音频列表指令

        Returns:
            GetAudioListResponse
        """
        timeout = 0
        if self.__is_serial:
            timeout = DEFAULT_TIMEOUT

        request = GetAudioListRequest()

        request.searchType = self.__search_type

        cmd_id = _PCProgramCmdId.GET_AUDIO_LIST_REQUEST.value
        return await self.send(cmd_id, request, timeout)

    def _parse_msg(self, message):
        """

        Args:
            message (Message):待解析的Message对象

        Returns:
            GetAudioListResponse
        """
        if isinstance(message, Message):
            data = message.bodyData
            response = GetAudioListResponse()
            response.ParseFromString(data)
            return response
        else:
            return None


class __PlayOnlineMusic(BaseApi):
    """播放在线歌曲api

    机器人播放QQ音乐在线歌曲，需在app绑定机器人并授权

    Args:
        is_serial (bool): 是否等待回复，默认True
        name (str): 歌曲名称，不能为空或者None

    #MusicResponse.isSuccess : 是否成功

    #MusicResponse.resultCode : 返回码

    """

    def __init__(self, is_serial: bool = True, name: str = None):
        assert name is not None and len(name), 'PlayOnlineMusic name should be available'
        self.__is_serial = is_serial
        self.__name = name
        self.__platform = ServicePlatform.TENCENT.value

    async def execute(self):
        """
        执行播放在线歌曲指令

        Returns:
            MusicResponse
        """
        timeout = 0
        if self.__is_serial:
            timeout = DEFAULT_TIMEOUT

        request = MusicRequest()

        request.platform = self.__platform
        request.name = self.__name

        cmd_id = _PCProgramCmdId.PLAY_ONLINE_MUSIC_REQUEST.value
        return await self.send(cmd_id, request, timeout)

    def _parse_msg(self, message):
        """

        Args:
            message (Message):待解析的Message对象

        Returns:
            MusicResponse
        """
        if isinstance(message, Message):
            data = message.bodyData
            response = MusicResponse()
            response.ParseFromString(data)
            return response
        else:
            return None


class ChangeRobotVolume(BaseApi):
    """设置机器人音量api

    调整机器人音量

    Args:
        is_serial (bool): 是否等待回复，默认True
        volume (float): 音量，范围[0.0,1.0]，默认0.5

    #ChangeRobotVolumeResponse.isSuccess : 是否成功

    #ChangeRobotVolumeResponse.resultCode : 返回码

    """

    def __init__(self, is_serial: bool = True, volume: float = 0.5):
        assert isinstance(volume, float) and 0.0 <= volume <= 1.0, 'ChangeRobotVolume : volume should be in range[' \
                                                                   '0.0,1.0] '
        self.__is_serial = is_serial
        self.__volume = volume

    async def execute(self):
        """发送设置机器人音量指令

        Returns:
            ChangeRobotVolumeResponse
        """
        timeout = 0
        if self.__is_serial:
            timeout = DEFAULT_TIMEOUT

        request = ChangeRobotVolumeRequest()
        request.volume = self.__volume

        cmd_id = _PCProgramCmdId.CHANGE_ROBOT_VOLUME_REQUEST.value
        return await self.send(cmd_id, request, timeout)

    def _parse_msg(self, message):
        """

        Args:
            message (Message):待解析的Message对象

        Returns:
            ChangeRobotVolumeResponse
        """
        if isinstance(message, Message):
            data = message.bodyData
            response = ChangeRobotVolumeResponse()
            response.ParseFromString(data)
            return response
        else:
            return None


@enum.unique
class RobotAudioRecordControlType(enum.Enum):
    """
    机器人录音控制类型
    """
    START_RECORD = 0  # 开始录音
    STOP_RECORD = 1  # 停止录音
    START_PLAY = 2  # 开始播放
    STOP_PLAY = 3  # 停止播放
    PAUSE_PLAY = 4  # 暂停播放
    CONTINUE_PLAY = 5  # 继续播放
    RENAME_FILE = 6  # 重命名文件


class ControlRobotAudioRecord(BaseApi):
    """控制机器人录音/播放api

    Args:
        is_serial (bool): 是否等待回复，默认True
        control_type (RobotAudioRecordControlType): 控制类型，默认START_RECORD，开始录音
        time_limit (int): 录音时长，单位ms，默认60000ms，即60s
        file_name (str): 录音文件存储名称
        new_file_name (str): 重命名录音文件的名称

    #ControlRobotRecordResponse.isSuccess : 是否成功

    #ControlRobotRecordResponse.resultCode : 返回码

    #ControlRobotRecordResponse.id : 生成的录音文件名

    """

    def __init__(self, is_serial: bool = True,
                 control_type: RobotAudioRecordControlType = RobotAudioRecordControlType.START_RECORD,
                 time_limit: int = 60000, file_name: str = None,
                 new_file_name: str = None):
        assert isinstance(control_type, RobotAudioRecordControlType), 'ControlRobotAudioRecord : control_type should ' \
                                                                      'be RobotAudioRecordControlType instance '
        self.__is_serial = is_serial
        self.__control_type = control_type.value
        self.__timeLimit = time_limit
        self.__id = file_name
        self.__newId = new_file_name

    async def execute(self):
        """发送控制录音指令

        Returns:
            ControlRobotRecordResponse
        """
        timeout = 0
        if self.__is_serial:
            timeout = DEFAULT_TIMEOUT
        request = ControlRobotRecordRequest()
        request.type = self.__control_type
        request.timeLimit = self.__timeLimit

        if isinstance(self.__id, str):
            request.id = self.__id

        if isinstance(self.__newId, str):
            request.newId = self.__newId

        cmd_id = _PCProgramCmdId.CONTROL_ROBOT_AUDIO_RECORD.value
        return await self.send(cmd_id, request, timeout)

    def _parse_msg(self, message):
        """

        Args:
            message (Message):待解析的Message对象

        Returns:
            ControlRobotRecordResponse
        """
        if isinstance(message, Message):
            data = message.bodyData
            response = ControlRobotRecordResponse()
            response.ParseFromString(data)
            return response
        else:
            return None


class RobotAudioStartRecord(ControlRobotAudioRecord):
    """机器人开始录音api

    控制机器人开始录音

    Args:
        is_serial (bool): 是否等待回复，默认True
        time_limit (int): 录音时长，单位ms，默认60000ms，即60s

    #ControlRobotRecordResponse.isSuccess : 是否成功

    #ControlRobotRecordResponse.resultCode : 返回码

    #ControlRobotRecordResponse.id : 生成的录音文件名

    """

    def __init__(self, is_serial: bool = True, time_limit: int = 60000):
        assert isinstance(time_limit, int) and time_limit > 0, f'{self.__class__.__name__}  : time_limit should be ' \
                                                               f'positive '
        ControlRobotAudioRecord.__init__(self, is_serial=is_serial, time_limit=time_limit,
                                         control_type=RobotAudioRecordControlType.START_RECORD)


class RobotAudioStopRecord(ControlRobotAudioRecord):
    """机器人停止录音api

    控制机器人停止录音

    Args:
        is_serial (bool): 是否等待回复，默认True

    #ControlRobotRecordResponse.isSuccess : 是否成功

    #ControlRobotRecordResponse.resultCode : 返回码

    #ControlRobotRecordResponse.id : 生成的录音文件名

    """

    def __init__(self, is_serial: bool = True):
        ControlRobotAudioRecord.__init__(self, is_serial=is_serial,
                                         control_type=RobotAudioRecordControlType.STOP_RECORD)


class RobotAudioStartPlay(ControlRobotAudioRecord):
    """机器人开始播放录音api

    控制机器人开始播放录音

    Args:
        is_serial (bool): 是否等待回复，默认True
        file_name (str): 录音文件名，不可为空或None

    #ControlRobotRecordResponse.isSuccess : 是否成功

    #ControlRobotRecordResponse.resultCode : 返回码

    #ControlRobotRecordResponse.id : 生成的录音文件名

    """

    def __init__(self, is_serial: bool = True, file_name: str = None):
        assert isinstance(file_name, str) and len(file_name), f'{self.__class__.__name__}  : file_name should be ' \
                                                              f'available '
        ControlRobotAudioRecord.__init__(self, is_serial=is_serial, file_name=file_name,
                                         control_type=RobotAudioRecordControlType.START_PLAY)


class RobotAudioStopPlay(ControlRobotAudioRecord):
    """机器人停止播放录音api

    控制机器人停止播放录音

    Args:
        is_serial (bool): 是否等待回复，默认True

    #ControlRobotRecordResponse.isSuccess : 是否成功

    #ControlRobotRecordResponse.resultCode : 返回码

    #ControlRobotRecordResponse.id : 生成的录音文件名

    """

    def __init__(self, is_serial: bool = True):
        ControlRobotAudioRecord.__init__(self, is_serial=is_serial, control_type=RobotAudioRecordControlType.STOP_PLAY)


class RobotAudioPausePlay(ControlRobotAudioRecord):
    """机器人暂停播放录音api

    控制机器人暂停播放录音

    Args:
        is_serial (bool): 是否等待回复，默认True

    #ControlRobotRecordResponse.isSuccess : 是否成功

    #ControlRobotRecordResponse.resultCode : 返回码

    #ControlRobotRecordResponse.id : 生成的录音文件名

    """

    def __init__(self, is_serial: bool = True):
        ControlRobotAudioRecord.__init__(self, is_serial=is_serial, control_type=RobotAudioRecordControlType.PAUSE_PLAY)


class RobotAudioContinuePlay(ControlRobotAudioRecord):
    """机器人继续播放录音api

    控制机器人继续播放录音

    Args:
        is_serial (bool): 是否等待回复，默认True

    #ControlRobotRecordResponse.isSuccess : 是否成功

    #ControlRobotRecordResponse.resultCode : 返回码

    #ControlRobotRecordResponse.id : 生成的录音文件名

    """

    def __init__(self, is_serial: bool = True):
        ControlRobotAudioRecord.__init__(self, is_serial=is_serial,
                                         control_type=RobotAudioRecordControlType.CONTINUE_PLAY)


class RobotAudioRenameFile(ControlRobotAudioRecord):
    """机器人重命名录音文件api

    控制机器人重命名录音文件

    Args:
        is_serial (bool): 是否等待回复，默认True
        file_name (str): 录音文件名，不可为空或None

    #ControlRobotRecordResponse.isSuccess : 是否成功

    #ControlRobotRecordResponse.resultCode : 返回码

    #ControlRobotRecordResponse.id : 生成的录音文件名

    """

    def __init__(self, is_serial: bool = True, file_name: str = None, new_file_name: str = None):
        assert isinstance(file_name, str) and len(file_name), f'{self.__class__.__name__} : file_name should be ' \
                                                              f'available '
        assert isinstance(new_file_name, str) and len(new_file_name), f'{self.__class__.__name__} : new_file_name ' \
                                                                      f'should be available '
        ControlRobotAudioRecord.__init__(self, is_serial=is_serial, file_name=file_name, new_file_name=new_file_name,
                                         control_type=RobotAudioRecordControlType.RENAME_FILE)



import asyncio

from mini import mini_sdk as MiniSdk
from mini.apis.api_content import LanType
from mini.apis.api_content import QueryWiKi, WikiResponse
from mini.apis.api_content import StartTranslate, TranslateResponse
from mini.apis.base_api import MiniApiResultType
from mini.dns.dns_browser import WiFiDevice
from test.test_connect import test_get_device_by_name


# 测试, 查询wiki
async def test_query_wiki():
    """查询百科demo

    查询百科，查询内容"优必选"，并等待结果，机器人播报查询结果

    #WikiResponse.isSuccess : 是否成功

    #WikiResponse.resultCode : 返回码

    """
    # query:查询关键字
    block: QueryWiKi = QueryWiKi(query='优必选')
    # response : WikiResponse
    (resultType, response) = await block.execute()

    print(f'test_query_wiki result: {response}')

    assert resultType == MiniApiResultType.Success, 'test_query_wiki timetout'
    assert response is not None and isinstance(response, WikiResponse), 'test_query_wiki result unavailable'
    assert response.isSuccess, 'query_wiki failed'


# 测试翻译接口
async def test_start_translate():
    """翻译demo

    使用百度翻译，把"张学友"，从中文翻译成英文，并等待结果，机器人播报翻译结果

    #TranslateResponse.isSuccess : 是否成功

    #TranslateResponse.resultCode : 返回码

    # query: 关键字

    # from_lan: 源语言

    # to_lan: 目标语言
    
    # platform: BAIDU, GOOGLE, TENCENT

    """

    block: StartTranslate = StartTranslate(query="张学友", from_lan=LanType.CN, to_lan=LanType.EN)
    # response: TranslateResponse
    (resultType, response) = await block.execute()

    print(f'test_start_translate result: {response}')

    assert resultType == MiniApiResultType.Success, 'test_start_translate timetout'
    assert response is not None and isinstance(response, TranslateResponse), 'test_start_translate result unavailable'
    assert response.isSuccess, 'start_translate failed'


async def main():
    device: WiFiDevice = await test_get_device_by_name()
    if device:
        await MiniSdk.connect(device)
        await MiniSdk.enter_program()
        await test_query_wiki()
        await test_start_translate()
        await MiniSdk.quit_program()
        await MiniSdk.release()


if __name__ == '__main__':
    asyncio.run(main())
